@@ -5,4 +5,9 @@ class Error(Exception):
 
 class ClientError(Error):
     """Raised when the client details are not valid"""
+    pass
+
+
+class ImageError(Error):
+    """Raised when the Image Returned is not valid"""
     pass
\ No newline at end of file
